@@ -4,7 +4,7 @@ Main interface for emr-containers service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_emr_containers import (
         Client,
         EMRContainersClient,
@@ -13,10 +13,8 @@ Usage::
         ListVirtualClustersPaginator,
     )
 
-    session = boto3.Session()
-
-    client: EMRContainersClient = boto3.client("emr-containers")
-    session_client: EMRContainersClient = session.client("emr-containers")
+    session = Session()
+    client: EMRContainersClient = session.client("emr-containers")
 
     list_job_runs_paginator: ListJobRunsPaginator = client.get_paginator("list_job_runs")
     list_managed_endpoints_paginator: ListManagedEndpointsPaginator = client.get_paginator("list_managed_endpoints")
