@@ -27,8 +27,7 @@ import sys
 from datetime import datetime
 from typing import Generic, Iterator, Sequence, TypeVar, Union
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .literals import EndpointStateType, JobRunStateType, VirtualClusterStateType
 from .type_defs import (
@@ -57,7 +56,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListJobRunsPaginator(Boto3Paginator):
+class ListJobRunsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators/#listjobrunspaginator)
@@ -79,7 +78,7 @@ class ListJobRunsPaginator(Boto3Paginator):
         """
 
 
-class ListManagedEndpointsPaginator(Boto3Paginator):
+class ListManagedEndpointsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators/#listmanagedendpointspaginator)
@@ -101,7 +100,7 @@ class ListManagedEndpointsPaginator(Boto3Paginator):
         """
 
 
-class ListVirtualClustersPaginator(Boto3Paginator):
+class ListVirtualClustersPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators/#listvirtualclusterspaginator)
