@@ -45,6 +45,7 @@ __all__ = (
     "DescribeJobRunRequestRequestTypeDef",
     "DescribeManagedEndpointRequestRequestTypeDef",
     "DescribeVirtualClusterRequestRequestTypeDef",
+    "SparkSqlJobDriverTypeDef",
     "SparkSubmitJobDriverTypeDef",
     "PaginatorConfigTypeDef",
     "ListJobRunsRequestRequestTypeDef",
@@ -199,6 +200,15 @@ DescribeVirtualClusterRequestRequestTypeDef = TypedDict(
     },
 )
 
+SparkSqlJobDriverTypeDef = TypedDict(
+    "SparkSqlJobDriverTypeDef",
+    {
+        "entryPoint": str,
+        "sparkSqlParameters": str,
+    },
+    total=False,
+)
+
 _RequiredSparkSubmitJobDriverTypeDef = TypedDict(
     "_RequiredSparkSubmitJobDriverTypeDef",
     {
@@ -406,6 +416,7 @@ JobDriverTypeDef = TypedDict(
     "JobDriverTypeDef",
     {
         "sparkSubmitJobDriver": SparkSubmitJobDriverTypeDef,
+        "sparkSqlJobDriver": SparkSqlJobDriverTypeDef,
     },
     total=False,
 )
